Crate weave_image

Crate weave_image 

Structs

ThumbnailResult
Result of processing a thumbnail.

Enums

Error
Errors that can occur during thumbnail processing.

Functions

download
Download image bytes from a URL.
download_async
Download image bytes from a URL asynchronously.
process_thumbnail
Download an image, resize to thumbnail, and compute the storage key.
resize_to_webp
Resize image bytes to a WebP thumbnail with cover crop from center.
thumbnail_key
Compute the thumbnail object key from a source URL.