Structs
- Thumbnail
Result - Result of processing a thumbnail.
Enums
- Error
- Errors that can occur during thumbnail processing.
Functions
- download
- Download image bytes from a URL.
- download_
async - Download image bytes from a URL asynchronously.
- process_
thumbnail - Download an image, resize to thumbnail, and compute the storage key.
- resize_
to_ webp - Resize image bytes to a WebP thumbnail with cover crop from center.
- thumbnail_
key - Compute the thumbnail object key from a source URL.